#include <iostream>
#include <cmath>

#include "QQbar_threshold/load_grid.hpp"
#include "QQbar_threshold/xsection.hpp"
#include "QQbar_threshold/structure_function.hpp"
#include "QQbar_threshold/integrate.hpp"
#include "QQbar_threshold/constants.hpp"

int main(){
  namespace QQt = QQbar_threshold;
  QQt::load_grid(QQt::grid_directory() + "ttbar_grid.tsv");
  constexpr double sqrt_s = 344.;
  constexpr double mu = 80.;
  constexpr double mu_width = 350.;
  constexpr double mt_PS = 171.5;
  constexpr double width = 1.33;
  QQt::options opt = QQt::top_options();
  opt.ISR_const = true;

  const double beta = QQt::ISR_log(sqrt_s, QQt::alpha_mZ);
  const auto integrand = [=](double t){
    const double x = 1 - std::pow(t, 1/beta);
    const double L = QQt::modified_luminosity_function(t, beta);
    const double sigma = QQt::ttbar_xsection(
        std::sqrt(x)*sqrt_s, {mu, mu_width}, {mt_PS, width}, QQt::N3LO,
        opt
    );
    return L*sigma;
  };

  constexpr double x_min = 330.*330./(sqrt_s*sqrt_s);
  const double t_max = std::pow(1 - x_min, beta);

  std::cout << QQt::integrate(integrand, 0, t_max) << '\n';
}
