/**
 * @file
 * @brief Non-resonant corrections
 *
 * @author  Andreas Maier <a.maier@tum.de>
 * @version 2.0.0
 *
 * @section LICENSE
 *
 * Copyright 2015 Andreas Maier
 *
 * This file is part of the QQbar_threshold library.
 *
 * The QQbar_threshold library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of
 * the License, or (at your option) any later version.
 *
 * The QQbar_threshold library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the QQbar_threshold library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */
#pragma once

#include "parameters.hpp"

namespace QQbar_threshold{
  namespace detail{
    //! Computes the non-resonant contribution to \f$\sigma(e^+e^- \to t\bar{t})\f$
    double R_nonres(parameters const & p);

    //! identifiers for precomputed integrals
    enum integral_type{
      h1V = 0, h1A, h1VA, h2V, h2A, h3V, h3A, h4V, h4A,
      h5, h6, h7, h8, h9, h10,
      first_integral_type = h1V,
      last_integral_type = h10
    };

    //! grid interpolation for precomputed integrals
    double h_interpolation(integral_type t, double x, double yw);

    enum NNLO_contribution{
      manual = 0,
      automated,
      first_NNLO_contribution = manual,
      last_NNLO_contribution = automated
    };

    //! grid interpolation for precomputed NNLO non-resonant contributions
    double NNLO_nonres_interpolation(NNLO_contribution t, double x, double yw);
  }
}
