#ifdef NDEBUG
#undef NDEBUG
#endif
#include <iostream>
#include <iomanip>
#include <array>

#include "Wilson_coefficients.hpp"
#include "xsection.hpp"
#include "load_grid.hpp"
#include "threshold.hpp"

#define TSTT(name,i) \
  std::cout << #name << ": "; \
  diff = name - results_top[i]; \
  std::cout << diff; \
  assert(std::abs(diff)/std::abs(results_top[i]) < ep);	\
  std::cout << " (ok)\n";


namespace qqt = QQbar_threshold;
int main(){
  using QQbar_threshold::load_grid;
  using QQbar_threshold::grid_directory;
  using namespace QQbar_threshold::pert_order;
  double constexpr ep = 1e-7;
  using QQbar_threshold::top_options;
  using zeta::pi;
  double change, diff;
  load_grid(grid_directory() + "ttbar_grid.tsv");
  auto opt = top_options();
  opt.resonant_only = true;
  auto opt_noEW = opt;
  opt_noEW.beyond_QCD = qqt::SM::QED | qqt::SM::Higgs;

  const double sqrt_s = 345.;
  const double mu = 80.;
  const double mu_w = 350.;
  const double mtPS = 171.5;
  const double width = 1.33;

  change =
    qqt::ttbar_xsection(sqrt_s, {mu, mu_w}, {mtPS, width}, qqt::N2LO, opt) -
    qqt::ttbar_xsection(sqrt_s, {mu, mu_w}, {mtPS, width}, qqt::N2LO, opt_noEW);
  diff = change + 0.0678960777472769;
  std::cout << "top, N2LO: " << diff;
  assert(std::abs(diff) < ep);
  std::cout << " (ok)\n";

  change =
    qqt::ttbar_xsection(sqrt_s, {mu, mu_w}, {mtPS, width}, qqt::N3LO, opt) -
    qqt::ttbar_xsection(sqrt_s, {mu, mu_w}, {mtPS, width}, qqt::N3LO, opt_noEW);
  diff = change + 0.0642830178607463;
  std::cout << "top, N3LO: " << diff;
  assert(std::abs(diff) < ep);
  std::cout << " (ok)\n";

  opt = qqt::bottom_options();

  load_grid(grid_directory() + "bbbar_grid.tsv");
  opt.contributions.Cv_QED[0] = 0;
  opt.contributions.Ca_QED[0] = 0;
  opt.contributions.Cv_WZ[0] = 0;
  opt.contributions.Ca_WZ[0] = 0;
  double no_EW = bbbar_R_ratio(qqt::threshold()+1e-3, 5, 5, N3LO, opt);
  opt.contributions.Cv_QED[0] = 1;
  opt.contributions.Ca_QED[0] = 1;
  opt.contributions.Cv_WZ[0] = 1;
  opt.contributions.Ca_WZ[0] = 1;
  double with_EW = bbbar_R_ratio(qqt::threshold()+1e-3, 5, 5, N3LO, opt);
  diff = no_EW-with_EW;
  std::cout << "bottom sanity test: " << diff;
  assert(diff < 1e-3);
  std::cout << " (ok)\n";
}
