#ifdef NDEBUG
#undef NDEBUG
#endif
#include <iostream>
#include <cassert>

#include "xsection.hpp"
#include "load_grid.hpp"

namespace qqt = QQbar_threshold;
int main(){
  constexpr double ep = 1e-8;

  qqt::load_grid(qqt::grid_directory() + "ttbar_grid.tsv");
  constexpr double sqrt_s = 345.;
  constexpr double mu = 80.;
  constexpr double mu_w = 350.;
  constexpr double mtPS = 171.5;
  constexpr double width = 1.33;
  constexpr auto order = qqt::NNLO;
  auto opt = qqt::top_options();
  opt.invariant_mass_cut = 50.;
  opt.contributions.nonresonant[1] = 0.;
  opt.contributions.v_width2 = {0.};
  opt.contributions.v_width_kinetic = {0.};
  opt.contributions.width_ep = {0.};

  const double xs_base = qqt::ttbar_xsection(
      sqrt_s, {mu, mu_w}, {mtPS, width}, order, opt
  );

  auto opt_width = opt;
  opt_width.contributions.v_width2 = {1.};
  double change = qqt::ttbar_xsection(
      sqrt_s, {mu, mu_w}, {mtPS, width}, order, opt_width
  ) - xs_base;
  double diff = std::abs(change - 0.00027849);
  std::cout << "v_width2: " << diff;
  assert(diff < ep);
  std::cout << " (ok)\n";

  opt_width = opt;
  opt_width.contributions.v_width_kinetic = {1.};
  change = qqt::ttbar_xsection(
      sqrt_s, {mu, mu_w}, {mtPS, width}, order, opt_width
  ) - xs_base;
  diff = std::abs(change + 0.00420566);
  std::cout << "v_width_kinetic: " << diff;
  assert(diff < ep);
  std::cout << " (ok)\n";

  opt_width = opt;
  opt_width.contributions.width_ep = {1.};
  change = qqt::ttbar_xsection(
      sqrt_s, {mu, mu_w}, {mtPS, width}, order, opt_width
  ) - xs_base;
  diff = std::abs(change - 0.00177036);
  std::cout << "v_width_ep: " << diff;
  assert(diff < ep);
  std::cout << " (ok)\n";

}
